@@ -79,15 +79,17 @@ def _get_large_pod() -> Pod:
 
     primary_container = V1Container(name="primary")
     resources = V1ResourceRequirements(
-        requests={"cpu": "46", "memory": "170Gi"},
-        limits={"cpu": "48", "memory": "192Gi"},
+        requests={"cpu": "90", "memory": "170Gi"},
+        limits={"cpu": "96", "memory": "192Gi"},
     )
     primary_container.resources = resources
 
     return Pod(
         pod_spec=V1PodSpec(
             containers=[primary_container],
-            tolerations=[V1Toleration(effect="NoSchedule", key="ng", value="big")],
+            tolerations=[
+                V1Toleration(effect="NoSchedule", key="ng", value="cpu-96-spot")
+            ],
         ),
         primary_container_name="primary",
     )
@@ -159,6 +161,16 @@ on-demand.
      - True
 """
 
+
+def cached_large_gpu_task(cache_version):
+    """Provides caching with resources defined by `large_gpu_task`."""
+    if cache_version is None:
+        raise ValueError("Must provide a cache version to a cached task.")
+    return task(
+        cache=True, cache_version=cache_version, task_config=_get_large_gpu_pod()
+    )
+
+
 small_gpu_task = task(task_config=_get_small_gpu_pod())
 """This task will get scheduled on a small GPU-enabled node.
 
@@ -186,6 +198,16 @@ on it.
      - True
 """
 
+
+def cached_small_gpu_task(cache_version):
+    """Provides caching with resources defined by `small_gpu_task`."""
+    if cache_version is None:
+        raise ValueError("Must provide a cache version to a cached task.")
+    return task(
+        cache=True, cache_version=cache_version, task_config=_get_small_gpu_pod()
+    )
+
+
 large_task = task(task_config=_get_large_pod())
 """This task will get scheduled on a large node.
 
@@ -213,6 +235,14 @@ on it.
      - True
 """
 
+
+def cached_large_task(cache_version):
+    """Provides caching with resources defined by `large_task`."""
+    if cache_version is None:
+        raise ValueError("Must provide a cache version to a cached task.")
+    return task(cache=True, cache_version=cache_version, task_config=_get_large_pod())
+
+
 medium_task = task(task_config=_get_medium_pod())
 """This task will get scheduled on a medium node.
 
@@ -240,6 +270,14 @@ on it.
      - True
 """
 
+
+def cached_medium_task(cache_version):
+    """Provides caching with resources defined by `medium_task`."""
+    if cache_version is None:
+        raise ValueError("Must provide a cache version to a cached task.")
+    return task(cache=True, cache_version=cache_version, task_config=_get_medium_pod())
+
+
 small_task = task(task_config=_get_small_pod())
 """This task will get scheduled on a small node.
 
@@ -263,3 +301,49 @@ small_task = task(task_config=_get_small_pod())
      - 0
      - False
 """
+
+
+def cached_small_task(cache_version):
+    """Provides caching with resources defined by `small_task`."""
+    if cache_version is None:
+        raise ValueError("Must provide a cache version to a cached task.")
+    return task(cache=True, cache_version=cache_version, task_config=_get_small_pod())
+
+
+def custom_task(cpu: int, memory: int):
+    """Returns a custom task configuration requesting
+    the specified CPU/RAM allocations
+
+    Args:
+        cpu: An integer number of cores to request, up to 48 cores
+        memory: An integer number of Gigabytes of RAM to request, up to 128 Gi
+    """
+    primary_container = V1Container(name="primary")
+    resources = V1ResourceRequirements(
+        requests={"cpu": str(cpu), "memory": f"{memory}Gi"},
+        limits={"cpu": "48", "memory": "128Gi"},
+    )
+    primary_container.resources = resources
+    if cpu < 48 and memory < 128:
+        task_config = Pod(
+            pod_spec=V1PodSpec(
+                containers=[primary_container],
+            ),
+            primary_container_name="primary",
+        )
+    elif cpu < 96 and memory < 180:
+        task_config = Pod(
+            pod_spec=V1PodSpec(
+                containers=[primary_container],
+                tolerations=[
+                    V1Toleration(effect="NoSchedule", key="ng", value="cpu-96-spot")
+                ],
+            ),
+            primary_container_name="primary",
+        )
+    else:
+        raise ValueError(
+            f"One of {cpu} < 96 or {memory} < 180 is not satisfied. Task requirements are too high."
+        )
+
+    return task(task_config=task_config)
