@@ -7,12 +7,12 @@ except ImportError:
     from typing_extensions import Annotated
 
 from flytekit.core.annotation import FlyteAnnotation
-from flytekit.core.context_manager import FlyteContext
+from flytekit.core.context_manager import FlyteContext, FlyteContextManager
 from flytekit.core.type_engine import TypeEngine, TypeTransformer
 from flytekit.models.literals import Literal
 from flytekit.types.file.file import FlyteFile, FlyteFilePathTransformer
 
-from latch.types.url import LatchURL
+from latch.types.utils import _is_valid_url
 
 
 class LatchFile(FlyteFile):
@@ -54,27 +54,39 @@ class LatchFile(FlyteFile):
     def __init__(
         self, path: Union[str, PathLike], remote_path: PathLike = None, **kwargs
     ):
-
-        if remote_path is not None:
-            self._remote_path = LatchURL(remote_path).url  # validates url string
+        if _is_valid_url(path) and remote_path is None:
+            self._remote_path = path
+        else:
+            self._remote_path = remote_path
 
         if kwargs.get("downloader") is not None:
             super().__init__(path, kwargs["downloader"], remote_path)
         else:
 
-            def noop():
-                ...
+            def downloader():
+                ctx = FlyteContextManager.current_context()
+                if (
+                    ctx is not None
+                    and hasattr(self, "_remote_path")
+                    and self._remote_path is not None
+                ):
+                    self.path = ctx.file_access.get_random_local_path(self._remote_path)
+                    return ctx.file_access.get_data(
+                        self._remote_path,
+                        self.path,
+                        is_multipart=False,
+                    )
 
-            super().__init__(path, noop, remote_path)
-
-        # This will manually download object to local disk in the case of a
-        # user wishing to access self locally without referencing the path
-        # through `__fspath__`, eg. through `self.local_path`.
-        self.__fspath__()
+            super().__init__(path, downloader, self._remote_path)
 
     @property
     def local_path(self) -> str:
         """File path local to the environment executing the task."""
+
+        # This will manually download object to local disk in the case of a
+        # user wishing to access the file without using `open`.
+        self.__fspath__()
+
         return self.path
 
     @property
@@ -83,7 +95,7 @@ class LatchFile(FlyteFile):
         return self._remote_path
 
     def __str__(self):
-        return f'LatchFile("{self.local_path}")'
+        return f'LatchFile("remote_path={self.remote_path}")'
 
 
 LatchOutputFile = Annotated[
@@ -134,7 +146,9 @@ class LatchFilePathTransformer(FlyteFilePathTransformer):
         def _downloader():
             return ctx.file_access.get_data(uri, local_path, is_multipart=False)
 
-        return LatchFile(local_path, uri, downloader=_downloader)
+        ret = LatchFile(local_path, uri, downloader=_downloader)
+        ret._remote_source = uri
+        return ret
 
 
 TypeEngine.register(LatchFilePathTransformer())
