@@ -1,6 +1,6 @@
 import pytest
 
-from latch.types.utils import InvalidLatchURL, _validate_latch_url
+from latch.types.utils import _is_valid_url
 
 
 def test_validate_latch_url():
@@ -9,12 +9,12 @@ def test_validate_latch_url():
         "latch:///foo/bar.txt",
         "latch:///foo/bar/",
         "latch:///foo/bar",
+        "s3:///foo/bar",
     )
-    invalid_urls = ("latch://foo.txt", "lach:///foo.txt")
+    invalid_urls = ("latch://foo.txt", "lach:///foo.txt", "gcp:///foo.txt")
 
     for url in valid_urls:
-        _validate_latch_url(url)
+        assert _is_valid_url(url) is True
 
     for url in invalid_urls:
-        with pytest.raises(InvalidLatchURL):
-            _validate_latch_url(url)
+        assert _is_valid_url(url) is False
